@@ -31,7 +31,7 @@ extern "C"
 {
 #endif
 
-#define GSASL_VERSION "0.1.0"
+#define GSASL_VERSION "0.1.1"
 
 /* Quoting RFC 2222:
    SASL mechanisms are named by strings, from 1 to 20 characters in
@@ -176,7 +176,7 @@ extern "C"
 /* Error handling: error.c */
   extern const char *gsasl_strerror (int err);
 
-/* Utilities: base64.c, md5pwd.c */
+/* Utilities: base64.c, md5pwd.c, crypto.c */
   extern int gsasl_base64_encode (char const *src,
 				  size_t srclength,
 				  char *target, size_t targsize);
@@ -185,7 +185,8 @@ extern "C"
   extern int gsasl_md5pwd_get_password (const char *filename,
 					const char *username,
 					char *key, size_t * keylen);
-  extern int gsasl_randomize (int strong, char *data, size_t datalen);
+  extern int gsasl_nonce (char *data, size_t datalen);
+  extern int gsasl_random (char *data, size_t datalen);
   extern int gsasl_md5 (const char *in, size_t inlen, char *out[16]);
   extern int gsasl_hmac_md5 (const char *key, size_t keylen,
 			     const char *in, size_t inlen, char *outhash[16]);
@@ -407,6 +408,7 @@ extern "C"
   extern void gsasl_server_application_data_set (Gsasl_session_ctx * sctx,
 						 void *application_data);
   extern void *gsasl_server_application_data_get (Gsasl_session_ctx * sctx);
+  extern int gsasl_randomize (int strong, char *data, size_t datalen);
 
 #ifdef __cplusplus
 }
